@@ -1,5 +1,13 @@
 #!/usr/bin/env perl
 
+# ====================================================================
+# This script is deprecated.  The Subversion developers recommend
+# using mailer.py for post-commit and post-revprop change
+# notifications.  If you wish to improve or add features to a
+# post-commit notification script, please do that work on mailer.py.
+# See http://svn.collab.net/repos/svn/trunk/tools/hook-scripts/mailer .
+# ====================================================================
+
 # ====================================================================
 # commit-email.pl: send a notification email describing either a
 # commit or a revprop-change action on a Subversion repository.
@@ -9,10 +17,10 @@
 #
 # This script requires Subversion 1.2.0 or later.
 #
-# $HeadURL: http://svn.collab.net/repos/svn/branches/1.5.x/tools/hook-scripts/commit-email.pl.in $
-# $LastChangedDate: 2008-04-01 15:12:17 +0000 (Tue, 01 Apr 2008) $
-# $LastChangedBy: glasser $
-# $LastChangedRevision: 30155 $
+# $HeadURL: http://svn.collab.net/repos/svn/branches/1.6.x/contrib/hook-scripts/commit-email.pl.in $
+# $LastChangedDate: 2008-11-11 05:00:22 +0000 (Tue, 11 Nov 2008) $
+# $LastChangedBy: psamuelson $
+# $LastChangedRevision: 34134 $
 #
 # ====================================================================
 # Copyright (c) 2000-2006 CollabNet.  All rights reserved.
@@ -557,7 +565,7 @@ foreach my $project (@project_settings_list)
 
     my @head;
     my $formatted_date;
-    if (defined $stdout)
+    if ($stdout)
       {
         $formatted_date = strftime('%a %b %e %X %Y', localtime());
         push(@head, "From $mail_from $formatted_date\n");
@@ -684,10 +692,10 @@ sub usage
       "  $0 --revprop-change REPOS REVNUM USER PROPNAME [-d diff_file] \\\n",
       "    [[-m regex] [options] [email_addr ...]] ...\n",
       "options are:\n",
+      "  -m regex              Regular expression to match committed path\n",
       "  --from email_address  Email address for 'From:' (overrides -h)\n",
       "  -h hostname           Hostname to append to author for 'From:'\n",
       "  -l logfile            Append mail contents to this log file\n",
-      "  -m regex              Regular expression to match committed path\n",
       "  -r email_address      Email address for 'Reply-To:'\n",
       "  -s subject_prefix     Subject line prefix\n",
       "  --summary             Use first line of commit log in subject\n",
@@ -702,10 +710,9 @@ sub usage
       "contains modifications to a path that matches the regular\n",
       "expression, then the action applies to the project.\n",
       "\n",
-      "Any of the following -h, -l, -r, -s, --summary, and --diff command\n",
-      "line options and following email addresses are associated with\n",
-      "this project.  The next -m resets the -h, -l, -r, -s, --summary,\n",
-      "and --diff command line options and the list of email addresses.\n",
+      "Any of the following email addresses and command line options\n",
+      "(other than -d) are associated with this project, until the next -m,\n",
+      "which resets the options and the list of email addresses.\n",
       "\n",
       "To support a single project conveniently, the script initializes\n",
       "itself with an implicit -m . rule that matches any modifications\n",
